@@ -14,7 +14,7 @@ from tensorflow.keras.layers import (Input,Reshape,Activation,Attention,MaxPool1
 import tensorflow.keras.layers as layers
 from tensorflow.keras.regularizers import l1, l2
 from tensorflow.keras.optimizers import Adam
-from ../../.viz.format import *
+from .Auto_format import *
 
 class generator:
     def __init__(self,
